@@ -5,9 +5,6 @@ OC.L10N.register(
     "Saved" : "Bewaar",
     "Download" : "Laai Af",
     "Close" : "Sluit",
-    "filter" : "filter",
-    "Language" : "Taal",
-    "Subscribe" : "Teken in",
     "by" : "deur",
     "from" : "van",
     "Play audio" : "Speel oudio af",
@@ -20,6 +17,7 @@ OC.L10N.register(
     "left" : "links",
     "Jump to previous article" : "Spring na vorige artikel",
     "Refresh" : "Verfris",
+    "Subscribe" : "Teken in",
     "Web address" : "Webadres",
     "Folder" : "Vouer",
     "No folder" : "Geen vouer",
