@@ -97,10 +97,11 @@ OC.L10N.register(
     "Unread articles" : "Lukemattomat artikkelit",
     "All articles" : "Kaikki artikkelit",
     "Settings" : "Asetukset",
-    "Disable mark read through scrolling" : "Poista käytöstä luetuksi merkitseminen vierittäessä",
+    "Disable mark read through scrolling" : "Älä merkitse luetuksi vierittäessä",
     "Compact view" : "Tiivis näkymä",
+    "Expand articles on key navigation" : "Laajenna artikkelit näppäimistöllä navigoidessa",
     "Show all articles" : "Näytä kaikki artikkelit",
-    "Reverse ordering (oldest on top)" : "Käänteinen järjestys (vanhimmat ylimpänä)",
+    "Reverse ordering (oldest on top)" : "Käänteinen järjestys (vanhimmat ensin)",
     "Subscriptions (OPML)" : "Tilaukset (OPML)",
     "Import" : "Tuo",
     "Export" : "Vie",
