@@ -7,9 +7,6 @@ OC.L10N.register(
     "Token expired or app not enabled! Reload the page!" : "Kenniteikn er útrunnið eða forrit ekki virkt! Þú ættir að hlaða síðunni aftur inn!",
     "Internal server error! Please check your data/nextcloud.log file for additional information!" : "Innri miðlaravilla! Athugaðu skrána data/nextcloud.log fyrir nánari upplýsingar!",
     "Request failed, Nextcloud is in currently in maintenance mode!" : "Fyrirspurn brást, Nextcloud er núna í viðhaldsham.",
-    "Can not add feed: Unable to parse feed" : "Gat ekki bætt við streymi: Það tókst ekki að þátta streymið",
-    "Can not add feed: Exists already" : "Gat ekki bætt við streymi: streymið er þegar til",
-    "Articles without feed" : "Greinar án fréttastreymis",
     "News" : "Fréttir",
     "An RSS/Atom feed reader" : "RSS/Atom streymislesari",
     "Use system cron for updates" : "Nota kerfis-cron fyrir uppfærslur",
