@@ -63,6 +63,8 @@ class Item extends Entity implements IAPI, \JsonSerializable
     protected $unread = false;
     /** @var bool */
     protected $starred = false;
+    /** @var string|null */
+    protected $categoriesJson;
 
     public function __construct()
     {
@@ -85,6 +87,7 @@ class Item extends Entity implements IAPI, \JsonSerializable
         $this->addType('fingerprint', 'string');
         $this->addType('unread', 'boolean');
         $this->addType('starred', 'boolean');
+        $this->addType('categoriesJson', 'string');
     }
 
     /**
@@ -123,11 +126,16 @@ class Item extends Entity implements IAPI, \JsonSerializable
 
     public function generateSearchIndex(): void
     {
+        $categoriesString = !is_null($this->getCategories())
+            ? implode('', $this->getCategories())
+            : '';
+
         $this->setSearchIndex(
             mb_strtolower(
                 html_entity_decode(strip_tags($this->getBody())) .
                 html_entity_decode($this->getAuthor()) .
                 html_entity_decode($this->getTitle()) .
+                html_entity_decode($categoriesString) .
                 $this->getUrl(),
                 'UTF-8'
             )
@@ -275,6 +283,22 @@ class Item extends Entity implements IAPI, \JsonSerializable
         return $this->unread;
     }
 
+    /**
+     * @return null|string
+     */
+    public function getCategoriesJson(): ?string
+    {
+        return $this->categoriesJson;
+    }
+
+    /**
+     * @return null|array
+     */
+    public function getCategories(): ?array
+    {
+        return json_decode($this->getCategoriesJson());
+    }
+
     /**
      * Turns entity attributes into an array
      */
@@ -301,6 +325,7 @@ class Item extends Entity implements IAPI, \JsonSerializable
             'rtl' => $this->getRtl(),
             'intro' => $this->getIntro(),
             'fingerprint' => $this->getFingerprint(),
+            'categories' => $this->getCategories()
         ];
     }
 
@@ -505,6 +530,24 @@ class Item extends Entity implements IAPI, \JsonSerializable
         return $this;
     }
 
+    public function setCategoriesJson(string $categoriesJson = null): self
+    {
+        if ($this->categoriesJson !== $categoriesJson) {
+            $this->categoriesJson = $categoriesJson;
+            $this->markFieldUpdated('categoriesJson');
+        }
+
+        return $this;
+    }
+
+    public function setCategories(array $categories = null): self
+    {
+        $categoriesJson = !is_null($categories) ? json_encode($categories) : null;
+        $this->setCategoriesJson($categoriesJson);
+
+        return $this;
+    }
+
     public function toAPI(): array
     {
         return [
@@ -534,11 +577,11 @@ class Item extends Entity implements IAPI, \JsonSerializable
     /**
      * Format for exporting.
      *
-     * @param $feeds
+     * @param array $feeds List of feeds
      *
      * @return array
      */
-    public function toExport($feeds): array
+    public function toExport(array $feeds): array
     {
         return [
             'guid' => $this->getGuid(),
@@ -579,7 +622,7 @@ class Item extends Entity implements IAPI, \JsonSerializable
     /**
      * Check if a given mimetype is supported
      *
-     * @param string $mime mimetype to check
+     * @param string|null $mime mimetype to check
      *
      * @return boolean
      */
