@@ -119,7 +119,7 @@ class FeedServiceV2 extends Service
         $feeds = $this->mapper->findAllFromUser($userId);
 
         foreach ($feeds as &$feed) {
-            $items = $this->itemService->findAllForFeed($feed->getId());
+            $items = $this->itemService->findAllInFeed($userId, $feed->getId());
             $feed->items = $items;
         }
         return $feeds;
@@ -189,15 +189,18 @@ class FeedServiceV2 extends Service
         bool $full_text = false,
         ?string $title = null,
         ?string $user = null,
-        ?string $password = null
+        ?string $password = null,
+        bool $full_discover = true
     ): Entity {
         if ($this->existsForUser($userId, $feedUrl)) {
             throw new ServiceConflictException('Feed with this URL exists');
         }
 
-        $feeds = $this->explorer->discover($feedUrl);
-        if ($feeds !== []) {
-            $feedUrl = array_shift($feeds);
+        if ($full_discover) {
+            $feeds = $this->explorer->discover($feedUrl);
+            if ($feeds !== []) {
+                $feedUrl = array_shift($feeds);
+            }
         }
 
         try {
@@ -205,7 +208,7 @@ class FeedServiceV2 extends Service
              * @var Feed   $feed
              * @var Item[] $items
              */
-            list($feed, $items) = $this->feedFetcher->fetch($feedUrl, true, '0', $full_text, $user, $password);
+            list($feed, $items) = $this->feedFetcher->fetch($feedUrl, $full_text, $user, $password);
         } catch (ReadErrorException $ex) {
             $this->logger->debug($ex->getMessage());
             throw new ServiceNotFoundException($ex->getMessage());
@@ -257,8 +260,6 @@ class FeedServiceV2 extends Service
              */
             list($fetchedFeed, $items) = $this->feedFetcher->fetch(
                 $location,
-                false,
-                $feed->getHttpLastModified(),
                 $feed->getFullTextEnabled(),
                 $feed->getBasicAuthUser(),
                 $feed->getBasicAuthPassword()
@@ -308,7 +309,7 @@ class FeedServiceV2 extends Service
         $feed->setLastUpdateError(null);
 
         $unreadCount = 0;
-        array_map(function (Item $item) use (&$unreadCount) {
+        array_map(function (Item $item) use (&$unreadCount): void {
             if ($item->isUnread()) {
                 $unreadCount++;
             }
@@ -341,4 +342,23 @@ class FeedServiceV2 extends Service
             $this->fetch($feed);
         }
     }
+
+    /**
+     * Mark a feed as read
+     *
+     * @param string   $userId    Feed owner
+     * @param int      $id        Feed ID
+     * @param int|null $maxItemID Highest item ID to mark as read
+     *
+     * @return int
+     *
+     * @throws ServiceConflictException
+     * @throws ServiceNotFoundException
+     */
+    public function read(string $userId, int $id, ?int $maxItemID = null): int
+    {
+        $feed = $this->find($userId, $id);
+
+        return $this->mapper->read($userId, $feed->getId(), $maxItemID);
+    }
 }
